@@ -1,4 +1,4 @@
-# Copyright 2004-2022 Bright Computing Holding BV
+# Copyright 2004-2023 Bright Computing Holding BV
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -44,6 +44,7 @@ from clusterondemand.bcm_version import BcmVersion
 from clusterondemand.cidr import cidr, must_be_within_cidr
 from clusterondemand.clustercreate import enable_cmd_debug_commands, generate_random_cluster_password
 from clusterondemand.clusternameprefix import must_start_with_cod_prefix
+from clusterondemand.configuration import CFG_NO_ADMIN_EMAIL
 from clusterondemand.exceptions import CODException, UserReportableException
 from clusterondemand.ip import nth_ip_in_default_network
 from clusterondemand.node_definition import NodeDefinition
@@ -332,6 +333,9 @@ class ClusterCreate(ClusterCommand):
 
         bs["bright"]["license"] = clusterondemand.brightsetup.get_license_dict()
 
+        if config["admin_email"] != CFG_NO_ADMIN_EMAIL:
+            bs["bright"]["admin_email"] = config["admin_email"]
+
         b["modules"]["brightsetup"] = bs
 
         return b
@@ -420,12 +424,18 @@ class ClusterCreate(ClusterCommand):
                 cloud_init_script += command + "\n"
 
         if config["run_cm_bright_setup"]:
+            if config["prebs"]:
+                cloud_init_script += "\n".join(["echo 'Starting custom prebs commands'", *config["prebs"], ""])
+
             if BcmVersion(config["version"]) < "8.2":
                 cloud_init_script += "/cm/local/apps/cluster-tools/bin/cm-bright-setup " \
-                                     "-c /root/cm/cm-bright-setup.conf --on-error-action abort"
+                                     "-c /root/cm/cm-bright-setup.conf --on-error-action abort\n"
             else:
                 cloud_init_script += "/cm/local/apps/cm-setup/bin/cm-bright-setup " \
-                                     "-c /root/cm/cm-bright-setup.conf --on-error-action abort"
+                                     "-c /root/cm/cm-bright-setup.conf --on-error-action abort\n"
+
+            if config["postbs"]:
+                cloud_init_script += "\n".join(["echo 'Starting custom postbs commands'", *config["postbs"], ""])
 
         return cloud_init_script
 
